class IcaAnalysisExample;
class IcaDetectorConstruction;
class IcaEventAction;

/* backwards compatibility for CLHEP 1.9 and onwards */
namespace CLHEP {} using namespace CLHEP;

void IcaG4(const char *batchfilename = 0)
{
  // choose the Random engine
  HepRandom::setTheEngine(new RanecuEngine());
  
  // Ica Verbose output class
  SetIcaSteppingVerbose();
  
  // construct the default run manager
  G4::NewG4();
  
  // start ("default") histograming
  IcaAnalysisExample *analysis = NewIcaAnalysisExample();
  
  // set mandatory initialization classes
  IcaDetectorConstruction *detector = NewIcaDetectorConstruction();
  SetIcaDetectorConstruction(detector);
  
  SetIcaPhysicsList(detector);
  
  if (!((batchfilename) && (*batchfilename))) G4::NewG4UIsession();
  
  // visualization manager
  SetIcaVisManager();
  G4::VisInitialise();
  
  // set user action classes
  SetIcaPrimaryGeneratorAction(detector);
  SetIcaRunAction();
  IcaEventAction *eventAction = NewIcaEventAction();
  SetIcaEventAction(eventAction);
  SetIcaStackingAction();
  SetIcaTrackingAction();
  SetIcaSteppingAction(eventAction);
  
  // execute IcaG4.PreInit.mac (if present)
  G4::ApplyCommand("/control/execute IcaG4.PreInit.mac");
  
  // initialize G4 kernel
  G4::Initialise();
  
  if ((batchfilename) && (*batchfilename))
    {
      // batch mode
      G4String command = "/control/execute ";
      command += batchfilename;
      G4::ApplyCommand(command);
    }
  else
    {
      // interactive mode
      G4::ApplyCommand("/control/execute vis.mac");
      // customize the menubar with a macro file
      G4::ApplyCommand("/control/execute vis/gui.mac");
      G4::SessionStart();
    }
  
  // job termination
  // DeleteIcaAnalysisExample(analysis);
  // G4::DeleteG4();
}

void g(void)
{
  /* load the G4 shared library */
  if ( (!gInterpreter->IsLoaded("G4/G4")) &&
       (!gInterpreter->IsLoaded("./G4/G4")) &&
       (!gInterpreter->IsLoaded(gSystem->ExpandPathName("${G4WORKDIR}/lib/${G4SYSTEM}/G4"))) )
    gSystem->Load(gSystem->ExpandPathName("${G4WORKDIR}/lib/${G4SYSTEM}/G4"));
  
  /* set the include path */
  if ( (gInterpreter->IsLoaded("G4/G4")) ||
       (gInterpreter->IsLoaded("./G4/G4")) )
    gSystem->AddIncludePath("-I./G4");
  else
    gSystem->AddIncludePath(gSystem->ExpandPathName("-I${G4WORKDIR}/include"));
  gSystem->AddIncludePath("-I./include");
  gSystem->AddIncludePath(gSystem->ExpandPathName("-I${G4INCLUDE}"));
  gSystem->AddIncludePath(gSystem->ExpandPathName("-I${CLHEP_INCLUDE_DIR}"));
  if (gSystem->Getenv("OGLFLAGS"))
    gSystem->AddIncludePath(gSystem->ExpandPathName("${OGLFLAGS}"));
  else if (gSystem->Getenv("OGLHOME"))
    gSystem->AddIncludePath(gSystem->ExpandPathName("-I${OGLHOME}/include"));
  
  /* user's classes MUST be precompiled !!! */
  /* ... first make the shared library */
  gSystem->Exec("gmake lib");
  
  /* ... then load it ... but ... only if it was not already loaded */
  if (!gInterpreter->IsLoaded(gSystem->ExpandPathName("${G4WORKDIR}/tmp/${G4SYSTEM}/IcaG4/libIcaG4")))
    gSystem->Load(gSystem->ExpandPathName("${G4WORKDIR}/tmp/${G4SYSTEM}/IcaG4/libIcaG4"));
  
  /* ... finally load the G4 <-> ROOT user's gluing routines */
  gROOT->LoadMacro("./s.cxx++");
  
  /* run the Geant4 simulation (interpreted) */
  //IcaG4();
}

/* end of file g.cxx for IcaG4 by Jacek M. Holeczek */
