//
// ********************************************************************
// * DISCLAIMER                                                       *
// *                                                                  *
// * The following disclaimer summarizes all the specific disclaimers *
// * of contributors to this software. The specific disclaimers,which *
// * govern, are listed with their locations in:                      *
// *   http://cern.ch/geant4/license                                  *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.                                                             *
// *                                                                  *
// * This  code  implementation is the  intellectual property  of the *
// * GEANT4 collaboration.                                            *
// * By copying,  distributing  or modifying the Program (or any work *
// * based  on  the Program)  you indicate  your  acceptance of  this *
// * statement, and all its terms.                                    *
// ********************************************************************
//
//
// $Id: IcaEventAction.cc,v 1.16 2002/01/09 17:24:13 ranjard Exp $
// GEANT4 tag $Name: geant4-04-00-patch-02 $
//
// 

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

#include "IcaEventAction.hh"
#include "IcaEventActionMessenger.hh"

#include "IcaAnalysisManager.hh"

#include "G4Event.hh"
#include "G4EventManager.hh"
#include "G4TrajectoryContainer.hh"
#include "G4Trajectory.hh"
#include "G4VVisManager.hh"
#include "G4SDManager.hh"
#include "G4UImanager.hh"
#include "G4ios.hh"
#include "G4UnitsTable.hh"

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

IcaEventAction::IcaEventAction()
:drawFlag("all"), printModulo(1),
 eventMessenger(0)
{
  eventMessenger = new IcaEventActionMessenger(this);
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

IcaEventAction::~IcaEventAction()
{
  delete eventMessenger;
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

void IcaEventAction::BeginOfEventAction(const G4Event* anEvent)
{
  G4int evtNb = anEvent->GetEventID();
  
  // Print this information event by event (modulo n)
  if (evtNb%printModulo == 0)
    {
      G4cout << "\n---> Begin of event: " << evtNb << G4endl;
      HepRandom::showEngineStatus();
    }
  
  // Histogramming
  if (gIcaAnalysisManager) gIcaAnalysisManager->BeginOfEventAction(anEvent);
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

void IcaEventAction::EndOfEventAction(const G4Event* anEvent)
{
  G4int evtNb = anEvent->GetEventID();
  
  // Print this information event by event (modulo n)
  if (evtNb%printModulo == 0) {
    G4cout << "---> End of event: " << evtNb << G4endl;
  }
  
  // Extract the trajectories and draw them
  if (G4VVisManager::GetConcreteInstance())
    {
      G4TrajectoryContainer* trajectoryContainer = anEvent->GetTrajectoryContainer();
      G4int n_trajectories = 0;
      if (trajectoryContainer) n_trajectories = trajectoryContainer->entries();
      
      for (G4int i=0; i<n_trajectories; i++)
        { G4Trajectory* trj = (G4Trajectory*)
	    ((*(anEvent->GetTrajectoryContainer()))[i]);
	if (drawFlag == "all") trj->DrawTrajectory(50);
	else if ((drawFlag == "charged")&&(trj->GetCharge() != 0.))
	  trj->DrawTrajectory(50);
	else if ((drawFlag == "neutral")&&(trj->GetCharge() == 0.))
	  trj->DrawTrajectory(50);
        }
    }
  
  // Histogramming
  if(gIcaAnalysisManager) gIcaAnalysisManager->EndOfEventAction(anEvent);
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo......

// end of file IcaEventAction.cc by Jacek M. Holeczek
