//
// ********************************************************************
// * DISCLAIMER                                                       *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.                                                             *
// *                                                                  *
// * By copying,  distributing  or modifying the Program (or any work *
// * based  on  the Program)  you indicate  your  acceptance of  this *
// * statement, and all its terms.                                    *
// ********************************************************************
//
//

#include "IcaStackingAction.hh"
#include "IcaStackingActionMessenger.hh"

#include "IcaAnalysisManager.hh"

#include "G4Track.hh"
#include "G4TrackStatus.hh"
#include "G4ParticleDefinition.hh"
#include "G4ParticleTypes.hh"
#include "G4ios.hh"

IcaStackingAction::IcaStackingAction()
{
  // new messenger
  theMessenger = new IcaStackingActionMessenger(this);
  
  // messenger defaults
  StackingOfSecondariesFlag = true;
}

IcaStackingAction::~IcaStackingAction()
{
  delete theMessenger;
}

G4ClassificationOfNewTrack 
IcaStackingAction::ClassifyNewTrack(const G4Track *aTrack)
{
  G4ClassificationOfNewTrack classification = fWaiting;
  
  G4String particleName = aTrack->GetDefinition()->GetParticleName();
  
  // if !StackingOfSecondariesFlag, stack only primaries
  if(aTrack->GetParentID() == 0)
    { classification = fUrgent; }
  else if(StackingOfSecondariesFlag)
    {
      // Immediately track secondary optical photons
      if(particleName == "opticalphoton") classification = fUrgent;
    }
  else
    { classification = fKill; }
  
  // Histogramming
  if (gIcaAnalysisManager) gIcaAnalysisManager->ClassifyNewTrack(aTrack, &classification);
  
  return classification;
}

void IcaStackingAction::NewStage()
{
  // Histogramming
  if (gIcaAnalysisManager) gIcaAnalysisManager->NewStage();
}

void IcaStackingAction::PrepareNewEvent()
{
  // Histogramming
  if (gIcaAnalysisManager) gIcaAnalysisManager->PrepareNewEvent();
}

// end of file IcaStackingAction.cc by Jacek M. Holeczek
